@@ -23,19 +23,19 @@ class ImageListing:
         my_payload= {}    
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url =  BASE_URL+"myaccount/api/v1/images/?apikey="+API_key+"&image_type=private"
+        url =  "api/v1/images/?apikey="+API_key+"&image_type=private"
         req="GET"
         status=Request(url, Auth_Token, my_payload, req).response.json()
 
-        Py_version_manager.py_print(status)            
+        print(status)            
             
         query=dict()
         
-        cpu=Py_version_manager.py_input("number of CPU ")
-        ram=Py_version_manager.py_input("capacity of RAM in GB ")
-        series=Py_version_manager.py_input("input the Series ")
-        OS=Py_version_manager.py_input("input the OS ")
-        Version=Py_version_manager.py_input("input the OS Version ")
+        cpu=input("number of CPU ")
+        ram=input("capacity of RAM in GB ")
+        series=input("input the Series ")
+        OS=input("input the OS ")
+        Version=input("input the OS Version ")
 
 
     
