@@ -32,10 +32,10 @@ class LBServices:
 
         if table.rowcount == 0:
             return "/"
-        Py_version_manager.py_print(table)
-        node_choice = Py_version_manager.py_input("Enter the Node ID: ")
+        print(table)
+        node_choice = input("Enter the Node ID: ")
         while( not Checks.is_int(node_choice) or not int(node_choice) in node_list_dict): 
-            node_choice = Py_version_manager.py_input("Enter a valid Node ID: ")
+            node_choice = input("Enter a valid Node ID: ")
         return int(node_choice)
 
     def assign_nodes(self, nodes_assigned_to_lb, api_key, auth_token):
@@ -51,44 +51,44 @@ class LBServices:
         node_choice = self.choice_nodes(nodes_assigned_to_lb, node_list_dict)
         if node_choice == '/':
             return nodes_assigned_to_lb
-        Py_version_manager.py_print("Node name: ", node_list_dict[node_choice]["name"])
-        Py_version_manager.py_print("Node ip: ", node_list_dict[node_choice]["public_ip_address"])
-        node_port = Py_version_manager.py_input("Enter the Node Port: ")
+        print("Node name: ", node_list_dict[node_choice]["name"])
+        print("Node ip: ", node_list_dict[node_choice]["public_ip_address"])
+        node_port = input("Enter the Node Port: ")
         while(not Checks.is_int(node_port)):
-            node_port = Py_version_manager.py_input("Enter the Node Port: ")
+            node_port = input("Enter the Node Port: ")
         nodes_assigned_to_lb.append(
             {"backend_name": node_list_dict[node_choice]["name"],
              "backend_ip": node_list_dict[node_choice]["private_ip_address"], "backend_port": node_port})
-        want_to_go_further = Py_version_manager.py_input("Enter y/n to add more nodes: ")
+        want_to_go_further = input("Enter y/n to add more nodes: ")
         while want_to_go_further.lower() == 'y':
             node_choice = self.choice_nodes(nodes_assigned_to_lb, node_list_dict)
             if node_choice == '/':
                 break
-            Py_version_manager.py_print("Node name: ", node_list_dict[node_choice]["name"])
-            Py_version_manager.py_print("Node ip: ", node_list_dict[node_choice]["private_ip_address"])
-            node_port = Py_version_manager.py_input("Enter the Node Port: ")
+            print("Node name: ", node_list_dict[node_choice]["name"])
+            print("Node ip: ", node_list_dict[node_choice]["private_ip_address"])
+            node_port = input("Enter the Node Port: ")
             while(not Checks.is_int(node_port)):
-                node_port = Py_version_manager.py_input("Enter the Node Port: ")
+                node_port = input("Enter the Node Port: ")
             nodes_assigned_to_lb.append(
                 {"backend_name": node_list_dict[node_choice]["name"],
                  "backend_ip": node_list_dict[node_choice]["private_ip_address"], 
                  "backend_port": node_port})
-            want_to_go_further = Py_version_manager.py_input("Enter y/n to add more nodes: ")
+            want_to_go_further = input("Enter y/n to add more nodes: ")
         return nodes_assigned_to_lb
 
     def classic_lb_creation(self, api_key, auth_token, nodes_assigned_to_lb, plan_assigned_to_lb):
-        Py_version_manager.py_print("(Note: All the fields having a important ahead of them can't be skipped)")
-        name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ")
+        print("(Note: All the fields having a important ahead of them can't be skipped)")
+        name_assigned_to_lb = input("Name of your lb(important): ")
         while(name_assigned_to_lb=="" or " " in name_assigned_to_lb):
-            name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ") 
-        Py_version_manager.py_print("Load Balancing Property: ")
+            name_assigned_to_lb = input("Name of your lb(important): ") 
+        print("Load Balancing Property: ")
         lb_balancing_property = {"1": "source",
                                  "2": "roundrobin"}
-        Py_version_manager.py_print("1. Source IP Hash")
-        Py_version_manager.py_print("2. Round Robin")
-        lb_balancing_property_choice = Py_version_manager.py_input(": ")
+        print("1. Source IP Hash")
+        print("2. Round Robin")
+        lb_balancing_property_choice = input(": ")
         while(not lb_balancing_property_choice in lb_balancing_property):
-            lb_balancing_property_choice = Py_version_manager.py_input("Please select from given choices only: ")
+            lb_balancing_property_choice = input("Please select from given choices only: ")
         balancing_property_assigned_to_lb = lb_balancing_property[lb_balancing_property_choice]
 
         nodes_assigned_to_lb = self.assign_nodes(nodes_assigned_to_lb, api_key, auth_token)
@@ -134,9 +134,9 @@ class LBServices:
         table.add_row(["7", "Suffix Match(Case-Sensitive)"])
         table.add_row(["8", "Regex Match(Case-Sensitive)"])
 
-        Py_version_manager.py_print(table)
+        print(table)
         acl_conditions = []
-        acl_condition_choice = Py_version_manager.py_input(": ")
+        acl_condition_choice = input(": ")
         if acl_condition_choice == "1":
             acl_conditions.append("path -i")
         elif acl_condition_choice == "2":
@@ -155,11 +155,11 @@ class LBServices:
             acl_conditions.append("path_reg")
         else:
             self.acl_condition_path()
-        path = Py_version_manager.py_input("Enter the value to be matched for previous option : ")
-        val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
+        path = input("Enter the value to be matched for previous option : ")
+        val_choice = input("Want to enter more values for the key(y/n): ")
         while val_choice.lower() == 'y':
-            path = path + " " + Py_version_manager.py_input("Enter value")
-            val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
+            path = path + " " + input("Enter value")
+            val_choice = input("Want to enter more values for the key(y/n): ")
         acl_conditions.append(path)
         return acl_conditions
 
@@ -170,8 +170,8 @@ class LBServices:
         table.add_row(["3", "Suffix Match"])
         table.add_row(["4", "Regex Match"])
 
-        Py_version_manager.py_print(table)
-        acl_condition_choice = Py_version_manager.py_input(": ")
+        print(table)
+        acl_condition_choice = input(": ")
         acl_conditions = []
         if acl_condition_choice == "1":
             acl_conditions.append("hdr(host) -i")
@@ -183,11 +183,11 @@ class LBServices:
             acl_conditions.append("hdr_reg(host) -i")
         else:
             self.acl_condition_host()
-        path = Py_version_manager.py_input("Enter value: ")
-        val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
+        path = input("Enter value: ")
+        val_choice = input("Want to enter more values for the key(y/n): ")
         while val_choice.lower() == 'y':
-            path = path + " " + Py_version_manager.py_input("Enter value")
-            val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
+            path = path + " " + input("Enter value")
+            val_choice = input("Want to enter more values for the key(y/n): ")
         acl_conditions.append(path)
         return acl_conditions
 
@@ -202,40 +202,40 @@ class LBServices:
         table.add_row(["7", "Suffix Match(Case-Sensitive)"])
         table.add_row(["8", "Regex Match(Case-Sensitive)"])
 
-        Py_version_manager.py_print(table)
+        print(table)
         acl_conditions = []
-        acl_condition_choice = Py_version_manager.py_input(": ")
+        acl_condition_choice = input(": ")
         if acl_condition_choice == "1":
-            key = Py_version_manager.py_input("Key: ")
+            key = input("Key: ")
             acl_conditions.append("urlp(" + key + ") -i")
         elif acl_condition_choice == "2":
-            key = Py_version_manager.py_input("Key: ")
+            key = input("Key: ")
             acl_conditions.append("urlp_beg(" + key + ") -i")
         elif acl_condition_choice == "3":
-            key = Py_version_manager.py_input("Key: ")
+            key = input("Key: ")
             acl_conditions.append("urlp_end(" + key + ") -i")
         elif acl_condition_choice == "4":
-            key = Py_version_manager.py_input("Key: ")
+            key = input("Key: ")
             acl_conditions.append("urlp_reg(" + key + ")")
         elif acl_condition_choice == "5":
-            key = Py_version_manager.py_input("Key: ")
+            key = input("Key: ")
             acl_conditions.append("urlp(" + key + ")")
         elif acl_condition_choice == "6":
-            key = Py_version_manager.py_input("Key: ")
+            key = input("Key: ")
             acl_conditions.append("urlp_beg(" + key + ")")
         elif acl_condition_choice == "7":
-            key = Py_version_manager.py_input("Key: ")
+            key = input("Key: ")
             acl_conditions.append("urlp_end(" + key + ")")
         elif acl_condition_choice == "8":
-            key = Py_version_manager.py_input("Key: ")
+            key = input("Key: ")
             acl_conditions.append("urlp_reg(" + key + ")")
         else:
             self.acl_condition_qpm()
-        path = Py_version_manager.py_input("Enter value: ")
-        val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
+        path = input("Enter value: ")
+        val_choice = input("Want to enter more values for the key(y/n): ")
         while val_choice.lower() == 'y':
-            path = path + " " + Py_version_manager.py_input("Enter value")
-            val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
+            path = path + " " + input("Enter value")
+            val_choice = input("Want to enter more values for the key(y/n): ")
         acl_conditions.append(path)
         return acl_conditions
 
@@ -250,10 +250,10 @@ class LBServices:
         table.add_row(["7", "CONNECT"])
         table.add_row(["8", "TRACE"])
 
-        Py_version_manager.py_print(table)
+        print(table)
         acl_conditions = []
         acl_conditions.append("method")
-        acl_condition_choice = Py_version_manager.py_input(": ")
+        acl_condition_choice = input(": ")
         if acl_condition_choice == "1":
             acl_conditions.append("HEAD")
         elif acl_condition_choice == "2":
@@ -276,22 +276,22 @@ class LBServices:
 
     def acl_condition_sip(self):
         acl_conditions = ["src"]
-        path = Py_version_manager.py_input("Enter Source IP: ")
+        path = input("Enter Source IP: ")
         while(path=="" or " "in path):
-            path = Py_version_manager.py_input("Enter a valid Source IP: ")
-        val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
+            path = input("Enter a valid Source IP: ")
+        val_choice = input("Want to enter more values for the key(y/n): ")
         while val_choice.lower() == 'y':
-            path = path + " " + Py_version_manager.py_input("Enter value")
-            val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
+            path = path + " " + input("Enter value")
+            val_choice = input("Want to enter more values for the key(y/n): ")
         acl_conditions.append(path)
         return acl_conditions
 
     def set_acl_rules(self, rule_count):
-        Py_version_manager.py_print(" ACL Rules")
+        print(" ACL Rules")
         acl_instance = dict()
         acl_instance["acl_name"] = "rule-" + str(rule_count)
-        Py_version_manager.py_print("Name     " + acl_instance["acl_name"])
-        Py_version_manager.py_print("Condition ")
+        print("Name     " + acl_instance["acl_name"])
+        print("Condition ")
         table = PrettyTable(["ID", "CONDITIONS"])
         table.add_row(["1", "PATH BASED"])
         table.add_row(["2", "HOST BASED"])
@@ -299,8 +299,8 @@ class LBServices:
         table.add_row(["4", "HTTP METHODS BASED"])
         table.add_row(["5", "SOURCE IP BASED"])
 
-        Py_version_manager.py_print(table)
-        condition_choice = Py_version_manager.py_input(": ")
+        print(table)
+        condition_choice = input(": ")
         if condition_choice == "1":
             condition_acl_list = self.acl_condition_path()
             acl_instance["acl_condition"] = condition_acl_list[0]
@@ -322,28 +322,28 @@ class LBServices:
             acl_instance["acl_condition"] = condition_acl_list[0]
             acl_instance["acl_matching_path"] = condition_acl_list[1]
         else:
-            Py_version_manager.py_print("please select out of the given choices only")
+            print("please select out of the given choices only")
             self.set_acl_rules(rule_count)
         return acl_instance
 
     def acl_rules(self, acl_rules_assigned):
         rule_count = 1
         acl_rules_assigned.append(self.set_acl_rules(rule_count))
-        add_more_rules = Py_version_manager.py_input("Want to add more rules(y/n): ")
+        add_more_rules = input("Want to add more rules(y/n): ")
         while add_more_rules.lower() == 'y':
             rule_count += 1
             acl_rules_assigned.append(self.set_acl_rules(rule_count))
-            add_more_rules = Py_version_manager.py_input("Want to add more rules(y/n): ")
+            add_more_rules = input("Want to add more rules(y/n): ")
         return acl_rules_assigned
 
     def backends(self, api_key, auth_token, backends_assigned_to_lb, nodes_assigned_to_backend):
-        Py_version_manager.py_print("Load Balancing Property: ")
+        print("Load Balancing Property: ")
         lb_balancing_property = {"1": "source",
                                  "2": "roundrobin"}
-        Py_version_manager.py_print("1. Source IP Hash")
-        Py_version_manager.py_print("2. Round Robin")
+        print("1. Source IP Hash")
+        print("2. Round Robin")
         prev_len = len(backends_assigned_to_lb)
-        lb_balancing_property_choice = Py_version_manager.py_input(": ")
+        lb_balancing_property_choice = input(": ")
         backends_assigned_to_lb.append({"balance": lb_balancing_property[lb_balancing_property_choice],
                                         "check_url": "/",
                                         "checkbox_enable": "null",
@@ -439,20 +439,20 @@ class LBServices:
                 table.add_row([backend_instance["backend_id"], backend_instance["backend_name"]])
         if table.rowcount == 0:
             return "/"
-        Py_version_manager.py_print(table)
-        backend_choice = Py_version_manager.py_input(": ")
+        print(table)
+        backend_choice = input(": ")
         return backend_choice
 
     def select_rules(self, acl_rules):
-        Py_version_manager.py_print("Choose a rule ")
+        print("Choose a rule ")
         rules_object_list = self.create_rules_objects(acl_rules)
         table = PrettyTable(["ID", "ACL RULE", "ACL RULE TYPE"])
         rule_id = 1
         for rule_instance in rules_object_list:
             table.add_row([rule_id, rule_instance["rule"], rule_instance["rule_type"]])
             rule_id += 1
-        Py_version_manager.py_print(table)
-        rule_choice = Py_version_manager.py_input(": ")
+        print(table)
+        rule_choice = input(": ")
         return rules_object_list[int(rule_choice) - 1]["rule"]
 
     def acl_maps(self, acl_maps_list, acl_rules, backends):
@@ -467,7 +467,7 @@ class LBServices:
                  }
             )
         backend_choice = self.set_backends(backend_server_list, rules_to_backends[your_rule_choice])
-        condition_state_choice = Py_version_manager.py_input("Enter ACL Condition State(T/F): ")
+        condition_state_choice = input("Enter ACL Condition State(T/F): ")
         if condition_state_choice.lower() == 't':
             condition_state_choice = "true"
         else:
@@ -476,7 +476,7 @@ class LBServices:
         acl_maps_list.append({"acl_backend": backend_server_list[int(backend_choice) - 1]["backend_name"],
                               "acl_condition_state": condition_state_choice,
                               "acl_name": your_rule_choice})
-        add_more_choice = Py_version_manager.py_input("Want to add more(y/n): ")
+        add_more_choice = input("Want to add more(y/n): ")
         while add_more_choice.lower() == 'y':
             your_rule_choice = self.select_rules(acl_rules)
             backend_server_list = []
@@ -489,7 +489,7 @@ class LBServices:
             backend_choice = self.set_backends(backend_server_list, rules_to_backends[your_rule_choice])
             if backend_choice == '/':
                 break
-            condition_state_choice = Py_version_manager.py_input("Enter ACL Condition State(T/F): ")
+            condition_state_choice = input("Enter ACL Condition State(T/F): ")
             if condition_state_choice.lower() == 't':
                 condition_state_choice = "true"
             else:
@@ -498,30 +498,30 @@ class LBServices:
             acl_maps_list.append({"acl_backend": backend_server_list[int(backend_choice) - 1]["backend_name"],
                                   "acl_condition_state": condition_state_choice,
                                   "acl_name": your_rule_choice})
-            add_more_choice = Py_version_manager.py_input("Want to add more(y/n): ")
+            add_more_choice = input("Want to add more(y/n): ")
         return acl_maps_list
 
     def advance_lb_creation(self, api_key, auth_token, acl_rules_assigned_to_lb, acl_maps_to_backends,
                             backends_assigned_to_lb, plan_assigned_to_lb):
-        Py_version_manager.py_print("(Note: All the fields having a important ahead of them can't be skipped)")
-        name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ")
+        print("(Note: All the fields having a important ahead of them can't be skipped)")
+        name_assigned_to_lb = input("Name of your lb(important): ")
         while(name_assigned_to_lb=="" or " " in name_assigned_to_lb):
-            name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ") 
-        Py_version_manager.py_print("Load Balancing Property: ")
+            name_assigned_to_lb = input("Name of your lb(important): ") 
+        print("Load Balancing Property: ")
         acl_rules_assigned_to_lb = self.acl_rules(acl_rules_assigned_to_lb)
         if not backends_assigned_to_lb:
             backends_assigned_to_lb = self.backends(api_key, auth_token, backends_assigned_to_lb, [])
-            add_more_backend = Py_version_manager.py_input("Want to add more backend(y/n): ")
+            add_more_backend = input("Want to add more backend(y/n): ")
             while add_more_backend.lower() == 'y':
                 backends_assigned_to_lb = self.backends(api_key, auth_token, backends_assigned_to_lb, [])
-                add_more_backend = Py_version_manager.py_input("Want to add more backend(y/n): ")
+                add_more_backend = input("Want to add more backend(y/n): ")
         else:
-            Py_version_manager.py_print("Choose Backend you want to edit")
+            print("Choose Backend you want to edit")
             table = PrettyTable(["Backend Server"])
             for backend_instance in backends_assigned_to_lb:
                 table.add_row(backend_instance["name"])
-            Py_version_manager.py_print(table)
-            backend_choice = Py_version_manager.py_input(": ")
+            print(table)
+            backend_choice = input(": ")
             backends_assigned_to_lb = self.backends(api_key, auth_token, backends_assigned_to_lb,
                                                     backends_assigned_to_lb[int(backend_choice)]["servers"])
         acl_maps_to_backends = self.acl_maps(acl_maps_to_backends, acl_rules_assigned_to_lb, backends_assigned_to_lb)
@@ -550,7 +550,7 @@ class LBServices:
         if api_key_credentials_object["message"] == "Invalid alias provided":
             return api_key_credentials_object
         else:
-            url =  BASE_URL+"myaccount/api/v1/appliances/?location=Delhi&apikey=" + \
+            url =  "api/v1/appliances/?location=Delhi&apikey=" + \
                   api_key_credentials_object["api_credentials"]["api_key"]
             payload = {}
             method = "GET"
@@ -573,14 +573,14 @@ class LBServices:
         if api_key_credentials_object["message"] == "Invalid alias provided":
             return api_key_credentials_object
         else:
-            Py_version_manager.py_print("Fill in the details required")
-            Py_version_manager.py_print("Choose the type of Load Balancer you want to use: ")
-            Py_version_manager.py_print("1. Classic Load Balancer")
-            Py_version_manager.py_print("2. Advanced Load Balancer")
-            choice_of_lb = Py_version_manager.py_input(": ")
+            print("Fill in the details required")
+            print("Choose the type of Load Balancer you want to use: ")
+            print("1. Classic Load Balancer")
+            print("2. Advanced Load Balancer")
+            choice_of_lb = input(": ")
             while (not Checks.is_int(choice_of_lb) or not 0<int(choice_of_lb)<=2):
-                Py_version_manager.py_print("please select out of the given choices only")
-                choice_of_lb = Py_version_manager.py_input(": ")
+                print("please select out of the given choices only")
+                choice_of_lb = input(": ")
             choice_of_lb=int(choice_of_lb)
             lb_plans = [
                 {
@@ -614,23 +614,23 @@ class LBServices:
                     "Price": " Rs16 /hour or  Rs11680 /mo"
                 }
             ]
-            Py_version_manager.py_print("Plans for load-balancers")
+            print("Plans for load-balancers")
             table = PrettyTable(["ID", "Plan", "Specs", "Price"])
             for plan_instance in lb_plans:
                 table.add_row([plan_instance["ID"], plan_instance["Plan"],
                                plan_instance["Specs"], plan_instance["Price"]])
-            Py_version_manager.py_print(table)
-            plan_choice = Py_version_manager.py_input(": ")
+            print(table)
+            plan_choice = input(": ")
             while (not Checks.is_int(plan_choice) or not 0<int(plan_choice)<=len(lb_plans)):
-                Py_version_manager.py_print("please select out of the given choices only")
-                plan_choice = Py_version_manager.py_input(": ")
+                print("please select out of the given choices only")
+                plan_choice = input(": ")
             plan_choice=int(plan_choice)
             plan_assigned_to_lb = lb_plans[plan_choice-1]["Plan"]
             if int(choice_of_lb) == 1:
                 payload = self.classic_lb_creation(api_key_credentials_object["api_credentials"]["api_key"],
                                                    api_key_credentials_object["api_credentials"]["api_auth_token"], [],
                                                    plan_assigned_to_lb)
-                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" \
+                url =  "api/v1/appliances/load-balancers/" \
                       "?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_object = Request(req="POST", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
@@ -641,7 +641,7 @@ class LBServices:
                 payload = self.advance_lb_creation(api_key_credentials_object["api_credentials"]["api_key"],
                                                    api_key_credentials_object["api_credentials"]["api_auth_token"], [],
                                                    [], [], plan_assigned_to_lb)
-                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" \
+                url =  "api/v1/appliances/load-balancers/" \
                       "?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_object = Request(req="POST", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
@@ -650,21 +650,21 @@ class LBServices:
                         "message": api_key_credentials_object["message"]}
 
     def delete_lb_sevice(self):
-        lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
+        lb_id = input("Enter the id of the lb: ")
         all_lb_in_list = self.get_lb_by_id(lb_id)
         while (all_lb_in_list is None or not Checks.is_int(lb_id)):
-            Py_version_manager.py_print("Please choose a valid load-balancer id: ")
-            lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
+            print("Please choose a valid load-balancer id: ")
+            lb_id = input("Enter the id of the lb: ")
             all_lb_in_list = self.get_lb_by_id(lb_id)
-        Py_version_manager.py_print("Deleting this lb instance can cause loss!")
-        choice = Py_version_manager.py_input("Do you still want to continue?(Y/N)")
+        print("Deleting this lb instance can cause loss!")
+        choice = input("Do you still want to continue?(Y/N)")
         if choice.upper() == "Y":
             api_key_credentials_object = self.alias_service_object.get_api_credentials()
             if api_key_credentials_object["message"] == "Invalid alias provided":
                 return api_key_credentials_object
             else:
 
-                url =  BASE_URL+"myaccount/api/v1/appliances/" + lb_id + "/?apikey=" + \
+                url =  "api/v1/appliances/" + lb_id + "/?apikey=" + \
                       api_key_credentials_object["api_credentials"]["api_key"]
 
                 payload = {}
@@ -677,7 +677,7 @@ class LBServices:
             return {"message": "Aborted"}
 
     def change_lb_name(self):
-        lb_name = Py_version_manager.py_input(" Enter Load-Balancer Name: ")
+        lb_name = input(" Enter Load-Balancer Name: ")
         payload = {"name": lb_name,
                    "type": "rename"}
 
@@ -687,16 +687,16 @@ class LBServices:
         table = PrettyTable(["Backend ID", "Backend Name"])
         for backend_index in range(0, len(backend_assigned)):
             table.add_row([str(backend_index + 1), "backend-server-" + str(backend_index + 1)])
-        Py_version_manager.py_print(table)
-        backend_choice = Py_version_manager.py_input(": ")
+        print(table)
+        backend_choice = input(": ")
         return backend_choice
 
     def select_node(self, nodes_assigned):
         table = PrettyTable(["Node ID", "Node Name"])
         for node_index in range(0, len(nodes_assigned)):
             table.add_row([str(node_index + 1), nodes_assigned[node_index]["backend_name"]])
-        Py_version_manager.py_print(table)
-        node_choice = Py_version_manager.py_input(": ")
+        print(table)
+        node_choice = input(": ")
         return node_choice
 
     def change_port_node(self, appliances):
@@ -704,20 +704,20 @@ class LBServices:
         backend_assigned = appliances_assigned["context"]["backends"]
         backend_choice = self.select_backend(backend_assigned)
         nodes_assigned = backend_assigned[int(backend_choice) - 1]["servers"]
-        Py_version_manager.py_print(" ")
+        print(" ")
         node_choice = self.select_node(nodes_assigned)
-        node_port = Py_version_manager.py_input(" Node Port: ")
+        node_port = input(" Node Port: ")
         nodes_assigned[int(node_choice) - 1]["backend_port"] = node_port
-        change_choice = Py_version_manager.py_input("Want to change more(y/n): ")
+        change_choice = input("Want to change more(y/n): ")
         while change_choice.lower() == 'y':
             backend_assigned = appliances_assigned["context"]["backends"]
             backend_choice = self.select_backend(backend_assigned)
             nodes_assigned = backend_assigned[int(backend_choice) - 1]["servers"]
-            Py_version_manager.py_print(" ")
+            print(" ")
             node_choice = self.select_node(nodes_assigned)
-            node_port = Py_version_manager.py_input(" Node Port: ")
+            node_port = input(" Node Port: ")
             nodes_assigned[int(node_choice) - 1]["backend_port"] = node_port
-            change_choice = Py_version_manager.py_input("Want to change more(y/n): ")
+            change_choice = input("Want to change more(y/n): ")
         payloads = {
             "acl_list": appliances_assigned["context"]["acl_list"],
             "acl_map": appliances_assigned["context"]["acl_map"],
@@ -743,18 +743,18 @@ class LBServices:
         backend_assigned = appliances_assigned["context"]["backends"]
         backend_choice = self.select_backend(backend_assigned)
         nodes_assigned = backend_assigned[int(backend_choice) - 1]["servers"]
-        Py_version_manager.py_print(" ")
+        print(" ")
         nodes_assigned = self.assign_nodes(nodes_assigned, api_credentials_object["api_credentials"]["api_key"],
                                            api_credentials_object["api_credentials"]["api_auth_token"])
-        change_choice = Py_version_manager.py_input("Want to change more(y/n): ")
+        change_choice = input("Want to change more(y/n): ")
         while change_choice.lower() == 'y':
             backend_assigned = appliances_assigned["context"]["backends"]
             backend_choice = self.select_backend(backend_assigned)
             nodes_assigned = backend_assigned[int(backend_choice) - 1]["servers"]
-            Py_version_manager.py_print(" ")
+            print(" ")
             nodes_assigned = self.assign_nodes(nodes_assigned, api_credentials_object["api_credentials"]["api_key"],
                                                api_credentials_object["api_credentials"]["api_auth_token"])
-            change_choice = Py_version_manager.py_input("Want to change more(y/n): ")
+            change_choice = input("Want to change more(y/n): ")
         payloads = {
             "acl_list": appliances_assigned["context"]["acl_list"],
             "acl_map": appliances_assigned["context"]["acl_map"],
@@ -780,20 +780,20 @@ class LBServices:
         if api_key_credentials_object["message"] == "Invalid alias provided":
             return api_key_credentials_object
         else:
-            lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
+            lb_id = input("Enter the id of the lb: ")
             all_lb_in_list = self.get_lb_by_id(lb_id)
             while(all_lb_in_list is None):
-                Py_version_manager.py_print("Please choose a valid load-balancer id: ")
-                lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
+                print("Please choose a valid load-balancer id: ")
+                lb_id = input("Enter the id of the lb: ")
                 all_lb_in_list = self.get_lb_by_id(lb_id)
-            Py_version_manager.py_print("  Please Make a Choice ")
-            Py_version_manager.py_print("1.  Change LoadBalancer Name")
-            Py_version_manager.py_print("2.  Change a Port of a Node")
-            Py_version_manager.py_print("3.  Add a new Port")
-            edit_choice = Py_version_manager.py_input(": ")
+            print("  Please Make a Choice ")
+            print("1.  Change LoadBalancer Name")
+            print("2.  Change a Port of a Node")
+            print("3.  Add a new Port")
+            edit_choice = input(": ")
             if edit_choice == str(1):
                 json_payload = self.change_lb_name()
-                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" + \
+                url =  "api/v1/appliances/load-balancers/" + \
                       lb_id + "/actions/?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_obj = Request(req="PUT", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
@@ -802,7 +802,7 @@ class LBServices:
                         "message": api_key_credentials_object["message"]}
             elif edit_choice == str(2):
                 json_payload = self.change_port_node(all_lb_in_list["appliance_instance"])
-                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" + \
+                url =  "api/v1/appliances/load-balancers/" + \
                       lb_id + "/?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_obj = Request(req="PUT", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
@@ -812,7 +812,7 @@ class LBServices:
 
             elif edit_choice == str(3):
                 json_payload = self.add_new_node(all_lb_in_list["appliance_instance"], api_key_credentials_object)
-                url =  BASE_URL+"myaccount/api/v1/appliances/load-balancers/" + \
+                url =  "api/v1/appliances/load-balancers/" + \
                       lb_id + "/?apikey=" + api_key_credentials_object["api_credentials"]["api_key"]
                 response_obj = Request(req="PUT", url=url, 
                 Auth_Token=api_key_credentials_object["api_credentials"]["api_auth_token"],
