@@ -11,5 +11,5 @@ def man_page():
         # print(MAN_PATH)
         subprocess.call(["man", MAN_PATH])
     else:
-        Py_version_manager.py_print("Man page not available for windows")
+        print("Man page not available for windows")
     
\ No newline at end of file
